# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class OrganizationDetails(Model):
    """Details of the organization of the certificate issuer.

    :param id: Id of the organization.
    :type id: str
    :param admin_details: Details of the organization administrator.
    :type admin_details:
     list[~azure.keyvault.v7_0.models.AdministratorDetails]
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'admin_details': {'key': 'admin_details', 'type': '[AdministratorDetails]'},
    }

    def __init__(self, *, id: str=None, admin_details=None, **kwargs) -> None:
        super(OrganizationDetails, self).__init__(**kwargs)
        self.id = id
        self.admin_details = admin_details



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# pylint: disable=line-too-long


from azure.mgmt.signalr.models import (
    CustomCertificate
)

from azure.mgmt.signalr._signal_rmanagement_client import (
    SignalRCustomCertificatesOperations
)


def custom_certificate_create(client: SignalRCustomCertificatesOperations, resource_group_name, signalr_name, name, keyvault_base_uri, keyvault_secret_name, keyvault_secret_version=None):
    custom_certificate = CustomCertificate(key_vault_base_uri=keyvault_base_uri, key_vault_secret_name=keyvault_secret_name, keyvault_secret_version=keyvault_secret_version)

    return client.begin_create_or_update(resource_group_name, signalr_name, name, custom_certificate)


def custom_certificate_delete(client: SignalRCustomCertificatesOperations, resource_group_name, signalr_name, name):
    return client.delete(resource_group_name, signalr_name, name)


def custom_certificate_show(client: SignalRCustomCertificatesOperations, resource_group_name, signalr_name, name):
    return client.get(resource_group_name, signalr_name, name)


def custom_certificate_list(client: SignalRCustomCertificatesOperations, resource_group_name, signalr_name):
    return client.list(resource_group_name, signalr_name)


def get_custom_certificate(client: SignalRCustomCertificatesOperations, resource_group_name, signalr_name, name):
    return client.get(resource_group_name, signalr_name, name)


def set_custom_certificate(client: SignalRCustomCertificatesOperations, resource_group_name, signalr_name, name, parameters):
    return client.begin_create_or_update(resource_group_name, signalr_name, name, parameters)


def update(instance: CustomCertificate, keyvault_base_uri=None, keyvault_secret_name=None, keyvault_secret_version=None):
    if keyvault_base_uri is not None:
        instance.key_vault_base_uri = keyvault_base_uri
    if keyvault_secret_name is not None:
        instance.key_vault_secret_name = keyvault_secret_name
    if keyvault_secret_version is not None:
        instance.key_vault_secret_version = keyvault_secret_version
    return instance



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
from collections import OrderedDict

linux_performance_collection_properties = [
    {
        'state': 'Enabled'
    }
]

linux_performance_object_properties = [
    {
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Memory",
        "performanceCounters": [
            {
                "counterName": "Available MBytes Memory"
            },
            {
                "counterName": "% Used Memory"
            },
            {
                "counterName": "% Used Swap Space"
            }
        ]
    },
    {
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Processor",
        "performanceCounters": [
            {
                "counterName": "% Processor Time"
            },
            {
                "counterName": "% Privileged Time"
            }
        ]
    },
    {
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Logical Disk",
        "performanceCounters": [
            {
                "counterName": "% Used Inodes"
            },
            {
                "counterName": "Free Megabytes"
            },
            {
                "counterName": "% Used Space"
            },
            {
                "counterName": "Disk Transfers/sec"
            },
            {
                "counterName": "Disk Reads/sec"
            },
            {
                "counterName": "Disk Writes/sec"
            }
        ]
    },
    {
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Network",
        "performanceCounters": [
            {
                "counterName": "Total Bytes Transmitted"
            },
            {
                "counterName": "Total Bytes Received"
            }
        ]
    }
]

linux_syslog_collection_properties = [
    {
        'state': 'Enabled'
    }
]

linux_syslog_properties = [
    {
        "syslogName": "syslog",
        "syslogSeverities": [
            {
                "severity": "notice"
            },
            {
                "severity": "info"
            },
            {
                "severity": "debug"
            }
        ]
    }
]

windows_event_properties = [
    {
        "eventLogName": "System",
        "eventTypes": [
            {
                "eventType": "Error"
            },
            {
                "eventType": "Warning"
            }
        ]
    }
]

windows_performance_counter_properties = [
    {
        "collectorType": "Default",
        "counterName": "Disk Transfers/sec",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "Disk Reads/sec",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "Bytes Total/sec",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Network Interface"
    },
    {
        "collectorType": "Default",
        "counterName": "Available MBytes",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Memory"
    },
    {
        "collectorType": "Default",
        "counterName": "% Free Space",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "Avg. Disk sec/Write",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "Bytes Received/sec",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Network Adapter"
    },
    {
        "collectorType": "Default",
        "counterName": "Current Disk Queue Length",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "% Processor Time",
        "instanceName": "_Total",
        "intervalSeconds": 10,
        "objectName": "Processor"
    },
    {
        "collectorType": "Default",
        "counterName": "Free Megabytes",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "Avg. Disk sec/Read",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "Bytes Sent/sec",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Network Adapter"
    },
    {
        "collectorType": "Default",
        "counterName": "% Committed Bytes In Use",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "Memory"
    },
    {
        "collectorType": "Default",
        "counterName": "Disk Writes/sec",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "LogicalDisk"
    },
    {
        "collectorType": "Default",
        "counterName": "Processor Queue Length",
        "instanceName": "*",
        "intervalSeconds": 10,
        "objectName": "System"
    }
]

default_linux_data_sources = OrderedDict()

default_linux_data_sources['LinuxPerformanceCollection'] = linux_performance_collection_properties
default_linux_data_sources['LinuxPerformanceObject'] = linux_performance_object_properties
default_linux_data_sources['LinuxSyslogCollection'] = linux_syslog_collection_properties
default_linux_data_sources['LinuxSyslog'] = linux_syslog_properties

default_windows_data_sources = OrderedDict()

default_windows_data_sources['WindowsEvent'] = windows_event_properties
default_windows_data_sources['WindowsPerformanceCounter'] = windows_performance_counter_properties



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ComputePolicy(Model):
    """The parameters used to create a new compute policy.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar name: The name of the compute policy
    :vartype name: str
    :ivar object_id: The AAD object identifier for the entity to create a
     policy for.
    :vartype object_id: str
    :ivar object_type: The type of AAD object the object identifier refers to.
     Possible values include: 'User', 'Group', 'ServicePrincipal'
    :vartype object_type: str or :class:`AADObjectType
     <azure.mgmt.datalake.analytics.account.models.AADObjectType>`
    :param max_degree_of_parallelism_per_job: The maximum degree of
     parallelism per job this user can use to submit jobs.
    :type max_degree_of_parallelism_per_job: int
    :param min_priority_per_job: The minimum priority per job this user can
     use to submit jobs.
    :type min_priority_per_job: int
    """

    _validation = {
        'name': {'readonly': True},
        'object_id': {'readonly': True},
        'object_type': {'readonly': True},
        'max_degree_of_parallelism_per_job': {'minimum': 1},
        'min_priority_per_job': {'minimum': 1},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'object_id': {'key': 'properties.objectId', 'type': 'str'},
        'object_type': {'key': 'properties.objectType', 'type': 'str'},
        'max_degree_of_parallelism_per_job': {'key': 'properties.maxDegreeOfParallelismPerJob', 'type': 'int'},
        'min_priority_per_job': {'key': 'properties.minPriorityPerJob', 'type': 'int'},
    }

    def __init__(self, max_degree_of_parallelism_per_job=None, min_priority_per_job=None):
        self.name = None
        self.object_id = None
        self.object_type = None
        self.max_degree_of_parallelism_per_job = max_degree_of_parallelism_per_job
        self.min_priority_per_job = min_priority_per_job



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class PendingCertificateSigningRequestResult(Model):
    """The pending certificate signing request result.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar value: The pending certificate signing request as Base64 encoded
     string.
    :vartype value: str
    """

    _validation = {
        'value': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PendingCertificateSigningRequestResult, self).__init__(**kwargs)
        self.value = None



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from collections import OrderedDict


def transform_account_list(result):
    transformed = []
    for r in result:
        res = OrderedDict([('Name', r['name']),
                           ('CloudName', r['cloudName']),
                           ('SubscriptionId', r['id']),
                           ('TenantId', r['tenantId']),
                           ('State', r.get('state')),
                           ('IsDefault', r['isDefault'])])
        transformed.append(res)
    return transformed



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class CertificateItem(Model):
    """The certificate item containing certificate metadata.

    :param id: Certificate identifier.
    :type id: str
    :param attributes: The certificate management attributes.
    :type attributes: ~azure.keyvault.v2016_10_01.models.CertificateAttributes
    :param tags: Application specific metadata in the form of key-value pairs.
    :type tags: dict[str, str]
    :param x509_thumbprint: Thumbprint of the certificate.
    :type x509_thumbprint: bytes
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'attributes': {'key': 'attributes', 'type': 'CertificateAttributes'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'x509_thumbprint': {'key': 'x5t', 'type': 'base64'},
    }

    def __init__(self, **kwargs):
        super(CertificateItem, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.attributes = kwargs.get('attributes', None)
        self.tags = kwargs.get('tags', None)
        self.x509_thumbprint = kwargs.get('x509_thumbprint', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class IssuerParameters(Model):
    """Parameters for the issuer of the X509 component of a certificate.

    :param name: Name of the referenced issuer object or reserved names; for
     example, 'Self' or 'Unknown'.
    :type name: str
    :param certificate_type: Type of certificate to be requested from the
     issuer provider.
    :type certificate_type: str
    :param certificate_transparency: Indicates if the certificates generated
     under this policy should be published to certificate transparency logs.
    :type certificate_transparency: bool
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'certificate_type': {'key': 'cty', 'type': 'str'},
        'certificate_transparency': {'key': 'cert_transparency', 'type': 'bool'},
    }

    def __init__(self, *, name: str=None, certificate_type: str=None, certificate_transparency: bool=None, **kwargs) -> None:
        super(IssuerParameters, self).__init__(**kwargs)
        self.name = name
        self.certificate_type = certificate_type
        self.certificate_transparency = certificate_transparency



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class IssuerCredentials(Model):
    """The credentials to be used for the certificate issuer.

    :param account_id: The user name/account name/account id.
    :type account_id: str
    :param password: The password/secret/account key.
    :type password: str
    """

    _attribute_map = {
        'account_id': {'key': 'account_id', 'type': 'str'},
        'password': {'key': 'pwd', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(IssuerCredentials, self).__init__(**kwargs)
        self.account_id = kwargs.get('account_id', None)
        self.password = kwargs.get('password', None)
